DERIVA Command-line clients
===========================

The following clients are available to interact with the DERIVA platform:

* [deriva-acl-config](deriva-acl-config.html) - Reads a configuration file and uses it to set ACLs for an ERMrest catalog (or for a schema or table within that catalog).
* [deriva-annotation-config](deriva-annotation-config.html) - Reads a configuration file and uses it to set annotations for an ERMrest catalog (or for a schema or table within that catalog). 
* [deriva-annotation-validate](deriva-annotation-validate.html) - Validates ERMrest catalog schema annotations against the DERIVA annotation specifications.
* [deriva-hatrac-cli ](deriva-hatrac-cli.html) - Interacts with the DERIVA Hatrac object store.
* [deriva-download-cli](deriva-download-cli.html) - Orchestrates the bulk export of tabular data (stored in ERMRest) and download of asset data (stored in Hatrac, or other supported HTTP-accessible object store).